@@ -7,6 +7,7 @@ Main application window
 
 from __future__ import unicode_literals
 import itertools
+import signal
 from gi.repository import Gtk, Gio, Gdk, GLib, GdkPixbuf
 from syncthing_gtk.tools import _
 from syncthing_gtk.tools import (
@@ -39,7 +40,7 @@ import os, webbrowser, sys, time, logging, shutil, re
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
-INTERNAL_VERSION		= "v0.9.4.3"
+INTERNAL_VERSION		= "v0.9.4.4"
 # Minimal Syncthing version supported by App
 MIN_ST_VERSION			= "0.14.50"
 
@@ -149,10 +150,24 @@ class App(Gtk.Application, TimerManager):
 	
 	def do_startup(self, *a):
 		Gtk.Application.do_startup(self, *a)
+		self.setup_signal_handlers()
 		self.setup_widgets()
 		self.setup_actions()
 		self.setup_statusicon()
 	
+	
+	def setup_signal_handlers(self):
+		def sigint(*a):
+			print("\n*break*")
+			sys.exit(0)
+		
+		def sigterm(*a):
+			log.error("SIGTERM recieved, exiting...")
+			self.quit()
+		
+		signal.signal(signal.SIGINT, sigint)
+		signal.signal(signal.SIGTERM, sigterm)
+	
 	def do_local_options(self, trash, lo):
 		self.parse_local_options(lo.contains)
 		return -1
@@ -170,7 +185,7 @@ class App(Gtk.Application, TimerManager):
 			self.show_wizard()
 		elif is_option("about"):
 			from syncthing_gtk.aboutdialog import AboutDialog
-			ad = AboutDialog(self, self.gladepath)
+			ad = AboutDialog(self, self.gladepath, self.iconpath)
 			ad.run([])
 			sys.exit(0)
 		
@@ -1061,23 +1076,27 @@ class App(Gtk.Application, TimerManager):
 			folder = self.folders[rid]
 			global_files = data["globalFiles"] + data["globalSymlinks"]
 			local_files = data["localFiles"] + data["localSymlinks"]
-			need_files = data["needFiles"] + data["needSymlinks"]
+			need_files = data["needFiles"] + data["needSymlinks"] + data.get("receiveOnlyTotalItems", 0)
+			need_bytes = data["needBytes"] + data.get("receiveOnlyChangedBytes", 0)
 			folder["global"] = "%s %s, %s" % (global_files, _("Files"), sizeof_fmt(data["globalBytes"]))
 			folder["local"]	 = "%s %s, %s" % (local_files, _("Files"), sizeof_fmt(data["localBytes"]))
-			folder["oos"]	 = "%s %s, %s" % (need_files, _("Files"), sizeof_fmt(data["needBytes"]))
-			if folder["folder_type"] == "sendonly":
+			folder["oos"]	 = "%s %s, %s" % (need_files, _("Files"), sizeof_fmt(need_bytes))
+			if folder["folder_type_s"] in ("sendonly", "receiveonly"):
 				can_override = (need_files > 0)
 				if can_override != folder["can_override"]:
 					folder["can_override"] = can_override
+					folder["override_title"] = (_("Cluster out of sync")
+												if folder["folder_type_s"] == "sendonly"
+												else _("Local changes"))
 					self.cb_syncthing_folder_up_to_date(None, rid)
 	
 	def cb_syncthing_folder_up_to_date(self, daemon, rid):
 		if rid in self.folders:	# Should be always
 			folder = self.folders[rid]
-			self.cb_syncthing_folder_state_changed(daemon, rid, 1.0,
-				COLOR_FOLDER_IDLE,
-				_("Cluster out of sync") if folder["can_override"] else _("Up to Date")
-			)
+			title = _("Up to Date")
+			if folder["can_override"]:
+				title = folder["override_title"]
+			self.cb_syncthing_folder_state_changed(daemon, rid, 1.0, COLOR_FOLDER_IDLE, title)
 		
 	def cb_syncthing_folder_state_changed(self, daemon, rid, percentage, color, text):
 		if rid in self.folders:	# Should be always
@@ -1165,7 +1184,7 @@ class App(Gtk.Application, TimerManager):
 			if online and folder.compare_color_hex(COLOR_FOLDER_OFFLINE):
 				# Folder was marked as offline but is back online now
 				if folder["can_override"]:
-					folder.set_status(_("Cluster out of sync"))
+					folder.set_status(folder["override_title"])
 				else:
 					folder.set_status(_("Up to Date"))
 				folder.set_color_hex(COLOR_FOLDER_IDLE)
@@ -1377,6 +1396,7 @@ class App(Gtk.Application, TimerManager):
 	
 	def show_folder(self, id, label, path, folder_type, ignore_perms, rescan_interval, fswatcher_enabled, shared):
 		""" Shared is expected to be list """
+		assert type(folder_type) != bool
 		display_path = path
 		if IS_WINDOWS:
 			if display_path.lower().replace("\\", "/").startswith(os.path.expanduser("~").lower()):
@@ -1404,7 +1424,8 @@ class App(Gtk.Application, TimerManager):
 			box.add_value("rescan",			"rescan.svg",	_("Rescan Interval"))
 			box.add_value("shared",			"shared.svg",	_("Shared With"))
 			# Add hidden stuff
-			box.add_hidden_value("folder_type", folder_type)
+			box.add_hidden_value("folder_type_s", folder_type)
+			box.add_hidden_value("override_title", "")
 			box.add_hidden_value("can_override", False)
 			box.add_hidden_value("devices", shared)
 			box.add_hidden_value("norm_path", os.path.abspath(os.path.expanduser(path)))
@@ -1427,7 +1448,6 @@ class App(Gtk.Application, TimerManager):
 		# Set values
 		box.set_value("id",		id)
 		box.set_value("path",	display_path)
-		assert type(folder_type) != bool
 		if folder_type == "receiveonly":
 			box.set_value("folder_type",	_("Receive Only"))
 		elif folder_type == "sendonly":
@@ -1811,8 +1831,14 @@ class App(Gtk.Application, TimerManager):
 	
 	def cb_popup_menu_folder(self, box, button, time):
 		self.rightclick_box = box
-		self["menu-popup-override"].set_visible(box["can_override"])
-		self["menu-separator-override"].set_visible(box["can_override"])
+		if box["can_override"]:
+			self["menu-popup-override"].set_visible(box["folder_type_s"] == "sendonly")
+			self["menu-popup-revert"].set_visible(box["folder_type_s"] == "receiveonly")
+			self["menu-separator-override"].set_visible(box["can_override"])
+		else:
+			self["menu-popup-override"].set_visible(False)
+			self["menu-popup-revert"].set_visible(False)
+			self["menu-separator-override"].set_visible(False)
 		self["popup-menu-folder"].popup(None, None, None, None, button, time)
 	
 	def cb_popup_menu_device(self, box, button, time):
@@ -1885,6 +1911,11 @@ class App(Gtk.Application, TimerManager):
 		log.info("Override folder %s", self.rightclick_box["id"])
 		self.daemon.override(self.rightclick_box["id"])
 	
+	def cb_menu_popup_revert(self, *a):
+		""" Handler for 'override local' context menu item """
+		log.info("Revert folder %s", self.rightclick_box["id"])
+		self.daemon.revert(self.rightclick_box["id"])
+	
 	def cb_menu_popup_delete_device(self, *a):
 		""" Handler for other 'edit' context menu item """
 		self.check_delete("device", self.rightclick_box["id"], self.rightclick_box.get_title())
@@ -2164,3 +2195,4 @@ class App(Gtk.Application, TimerManager):
 				self.cb_daemon_exit(self.process, -1)
 			else:
 				self.quit()
+
